// ---------------------------------------------------------------------------------------------------------------------
// Copyright (c) 2024 All rights reserved. Confidential.
// Author:   Tobias Goeckel
// ---------------------------------------------------------------------------------------------------------------------

/** Disables the selectability of all controls. This may be useful in older IE versions. */
function General_DisableSelection()
{
    var elements = document.getElementsByTagName("div");
    for (var i = 0; i < elements.length; i++) 
    {
        elements[i].onselectstart = function(event) 
        {
            window.event.returnValue = false;
        }
    }
}

/** Gets the connected windows form. */
function General_GetForm()
{
    return window.external;
}

/** Whether the given element contains a specific class item in its class attribute. */
function General_ContainsClass(element, targetClass) 
{
    return element.className.indexOf(targetClass) > -1;
}

/** Whether the control has the enabled_1 class item. */
function General_IsControlEnabled(controlId) 
{
    var element = document.getElementById(controlId);
    return General_ContainsClass(element, "enabled_1");
}

/** Toggles the visibility of the password in an input control. */
function General_TogglePasswordVisibility(controlId) 
{
    var element = document.getElementById(controlId);
    var typeValue = element.getAttribute("type");
    if(typeValue == "text")
    {
        typeValue = "password";
    }
    else
    {
        typeValue = "text";
    }
    element.setAttribute("type", typeValue);
}

/** Gets the text portion currently selected in the given element for example a textarea. */
function General_GetSelectedTextFromElement(elementId) 
{
    // General_Log("General_GetSelectedTextFromElement elementId=" + elementId);
    // Gets the textarea by id.
    var element = document.getElementById(elementId);
    var start = element.selectionStart;
    var end = element.selectionEnd;
    var selectedText = element.value.substring(start, end);
    return selectedText;
}

/** Overwrites the currently selected text portion in the given element for example a textarea with the given text. */
function General_OverwriteSelectedTextOfElement(elementId, newText) 
{
    // Gets the textarea by id.
    var element = document.getElementById(elementId);
    var start = element.selectionStart;
    var end = element.selectionEnd;

    element.selectionStart = 0;
    element.selectionEnd = 0;    
    element.value = element.value.substring(0, start) + newText + element.value.substring(end, element.value.length);
    element.selectionStart = start;
    element.selectionEnd = start + newText.length;
}

/** Selects a new text portion inside the given element. */
function General_SetTextSelection(elementId, start, end)
{
    // Gets the textarea by id.
    var element = document.getElementById(elementId);
    element.selectionStart = start;
    element.selectionEnd = end;  
}

/** Logs the given text to the log element. If the log element does not exist this method does nothing. */
function General_Log(text)
{
    var element = document.getElementById("log");
    if(element === null)
        return;
    element.value += text + "\r\n";
}

/** Gets the line count of the given text using regex. */
function General_GetLineCountViaRegex(text) 
{
    if(text === null)
        return 0;

    var count = text.split(/\n/).length;
    return count;
}

/** Gets the line count of the given text using indexOf. */
function General_GetLineCountViaIndexOf(text) 
{
    if(text == null)
        return 0;
    var count = 0;
    var index = 0;
    while(index >= 0)
    {
        index = text.indexOf('\n', index + 1);
        count++;
    }
    return count;
}


function General_SetVisible(element, visible)
{
    if(visible)
    {
        // element.style.display = '';
        element.style.visibility = 'visible';
    }
    else
    {
        // element.style.display = 'none';
        element.style.visibility = 'hidden';
    }
}

function General_Init_ButtonReload()
{
    var buttonReload = document.getElementById('buttonReload');
    buttonReload.addEventListener('click', function(event)
    {
        OnButtonClick(buttonReload.id);
    });
    return buttonReload;
}

function General_Init_ButtonMinimize()
{
    var buttonMinimize = document.getElementById('buttonMinimize');
    buttonMinimize.addEventListener('click', function(event)
    {
        OnButtonClick(buttonMinimize.id);
    });
    return buttonMinimize;
}

function General_Init_ButtonClose()
{
    var buttonClose = document.getElementById('buttonClose');
    buttonClose.addEventListener('click', function(event)
    {
        OnButtonClick(buttonClose.id);
    });
    return buttonClose;
}

function General_Init_Log()
{
    var element = document.getElementById('log');
    if(element === null)
        return;
    // Event contextmenu is called on rightclick.
    element.addEventListener('contextmenu', function(event)
    {
        element.value = "";
    });
    return element;
}


/** Forwards the button click to the connected windows form.  */
function OnButtonClick(controlId)
{
    if (General_IsControlEnabled(controlId)) 
    {
        General_GetForm().OnButtonClick(controlId)
    }
}

function OnPlayerClicked(controlId, playerName)
{
    if (General_IsControlEnabled(controlId)) 
    {
        General_GetForm().OnPlayerClicked(playerName)
    }
}